@@ -43,6 +43,8 @@ class LIB:
                               }
                              ).json()
 
+
+
     @staticmethod
     def getPID():
         return os.getpid()
@@ -57,6 +59,7 @@ class LIB:
         finally:
             return result
 
+
     @staticmethod
     def colunas_cursor(cursor) -> list:
         header = [head[0] for head in cursor.description]
@@ -77,7 +80,12 @@ class LIB:
         except Exception as error:
             decoded = error
         finally:
-            return decodede
+            return decoded
+
+    @staticmethod
+    def token_get() -> str:
+        key = Fernet.generate_key()
+        return key.decode("ascii")
 
     @staticmethod
     def findchar(string: str, pattern: str, ocorrencia: int = None, inicio: int = 0, fim: int = 0, trim: bool = True):
@@ -316,29 +324,26 @@ class LIB:
             return result
 
     @staticmethod
-    def token_get() -> str:
-        key = Fernet.generate_key()
-        cipher_suite = Fernet(key)
-        # return key.decode("ascii")
-        return cipher_suite
-
-    @staticmethod
-    def CRYPTOGRAPHY(word: str, token: str = None, action: str = "E"):
-        msg, result = None, None
+    def CRYPTOGRAPHY(word, action: str = "D", token: str = None):
+        # D=Decrypt, E=Encrypt
+        result = None
         try:
+            if word is None:
+                raise Exception(f"""Parametro "word" é obrigatorio!""")
+            if token is None:
+                raise Exception(f"""Parametro "token" é obrigatório""")
+            if isinstance(word, str):
+                word = word.encode()
+            CIPHER = Fernet(token)
             if action == "E":
-                if isinstance(word, str):
-                    word = word.encode()
-                result = token.encrypt(word).decode()
+                if type(word == "str"):
+                    result = CIPHER.encrypt(word)
             else:
-                if isinstance(word, str):
-                    word = word.encode()
-                result = token.decrypt(word).decode()
+                result = CIPHER.decrypt(word)
         except Exception as error:
-            msg = error.args[0]
-            result = msg
+            result = error.encode()
         finally:
-            return result
+            return result.decode()
 
     @staticmethod
     def cores_ansi() -> dict:
